:orphan:

.. _ug-mixed_precision_quantization_config:


===========================================
mixed_precision_quantization_config Module
===========================================

MixedPrecisionMetricsWeighting
================================
**Enum to select a method for quantization threshold selection:**

.. autoclass:: model_compression_toolkit.MixedPrecisionMetricsWeighting


|

KPI
================================
**Enum to select a method for quantization threshold selection:**

.. autoclass:: model_compression_toolkit.KPI


|


MixedPrecisionQuantizationConfig
=================================
**Class to configure the quantization process of the model:**

.. autoclass:: model_compression_toolkit.MixedPrecisionQuantizationConfig

